(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[      7149,        199]
NotebookOptionsPosition[      5619,        169]
NotebookOutlinePosition[      6176,        190]
CellTagsIndexPosition[      6133,        187]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 8, Section 8.5, Table 8.5", "Section",ExpressionUUID->"4ba0636f-1639-4e46-af9b-04af528f9ad0"],

Cell[TextData[{
 "Use the definition of ",
 StyleBox["LaplaceCoefficient", "Input"],
 " from the ",
 StyleBox["DisturbingFunction", "Input"],
 " package."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"913de107-c161-4c3b-9f79-efc9982c274e"],

Cell["\<\
LaplaceCoefficient[s_,jj_Integer,a_,n_Integer]:=
  Module[{outside,j=Abs[jj],cterm,cbterm,csum,i,k},
    outside=2*Product[s+k,{k,0,j-1}]/j!*a^(j-n);
    cterm=1;
    cbterm=cterm*Product[j-k,{k,0,n-1}];
    For[i=1; csum=cbterm,(cbterm>$MachineEpsilon)||(cbterm\[Equal]0),i++,
      cterm=cterm*(s+i-1)*(s+j+i-1)/i/(j+i)*a^2;
      cbterm=cterm*Product[j+2*i-k,{k,0,n-1}];
      csum=csum+cbterm];
    Expand[outside*csum]]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"43f48678-84f2-41ed-ac5a-56159826e0e8"],

Cell[TextData[{
 "Define a function, ",
 StyleBox["AlphaValues", "Input"],
 ", to return \[Alpha], \[Alpha]",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "1"], "(", "\[Alpha]", ")"}], TraditionalForm]],
  ExpressionUUID->"7feeb78e-a8ee-48b8-9692-8a30a33fb977"],
 " and \[Alpha]",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", 
     StyleBox["d",
      FontSlant->"Plain"]], "(", "\[Alpha]", ")"}], TraditionalForm]],
  ExpressionUUID->"97752b98-4028-41f7-ab7e-0cb67963bbba"],
 " for each resonance specified by ",
 StyleBox["p",
  FontSlant->"Italic"],
 "+",
 StyleBox["q",
  FontSlant->"Italic"],
 " and ",
 StyleBox["p",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"864d858a-8ec7-4dec-bd48-f8aad737966a"],

Cell["\<\
AlphaValues[{ppq_, p_}] :=
Module[{j=ppq, \[Alpha] = N[(p/(ppq))^(2/3)]},
f1 = 
 (1/8)*(2*\[Alpha]*LaplaceCoefficient[1/2, 0, \[Alpha], 1] +
        \[Alpha]^2*LaplaceCoefficient[1/2, 0, \[Alpha], 2]);
If[ppq-p == 1, 
fd =
 (1/2)*(-2*j*LaplaceCoefficient[1/2, j, \[Alpha], 0] +
        -\[Alpha]*LaplaceCoefficient[1/2, j, \[Alpha], 1])];
If[ppq-p == 2,
fd =
 (1/8)*((-5*j + 4*j^2)*LaplaceCoefficient[1/2, j, \[Alpha], 0] +
        (-2*\[Alpha] + 4*j*\[Alpha])*LaplaceCoefficient[1/2, j, \[Alpha], 1] \
+
         \[Alpha]^2*LaplaceCoefficient[1/2, j, \[Alpha], 2])];
{ppq, p, \[Alpha], \[Alpha]*f1, \[Alpha]*fd}
]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"8588d9ca-c17f-45a2-8356-ad3aad4ab663"],

Cell["Select the resonances for the table.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"715e3b9b-89ca-47e8-828f-a8b583f7d4f7"],

Cell["\<\
resonances = {{2,1}, {3,2}, {4,3}, {5,4}, {6,5},
              {3,1}, {5,3}, {7,5}, {9,7}, {11,9}};\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[3]:=",ExpressionUUID->"f45e9f14-e1f7-4fc7-bd95-c945ced2caff"],

Cell["Generate the values for the table.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e009b77f-2601-4fe0-9112-97261ef4393d"],

Cell["table = Map[AlphaValues[#]&, resonances];", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"09be7e2a-89c7-4fec-a471-c1855bc07bd9"],

Cell["Display the results.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ad334172-f303-4e05-b03f-5d22122516d6"],

Cell["TableForm[table]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[5]:=",ExpressionUUID->"65913616-951a-4a9a-9055-a326865bbdb7"],

Cell[BoxData[
 TagBox[GridBox[{
    {"2", "1", "0.6299605249474366`", "0.2441899723065255`", 
     RowBox[{"-", "0.7499640348438882`"}]},
    {"3", "2", "0.7631428283688879`", "0.879750899920926`", 
     RowBox[{"-", "1.5455341716765854`"}]},
    {"4", "3", "0.8254818122236567`", "1.8814737654896991`", 
     RowBox[{"-", "2.344724836584575`"}]},
    {"5", "4", "0.8617738760127535`", "3.244939511355182`", 
     RowBox[{"-", "3.145145660198443`"}]},
    {"6", "5", "0.8855488076521759`", "4.9685680346212955`", 
     RowBox[{"-", "3.9461319300367697`"}]},
    {"3", "1", "0.4807498567691362`", "0.0683812436998876`", 
     "0.28785249337965063`"},
    {"5", "3", "0.7113786608980126`", "0.5156566652853578`", 
     "2.3289164094706996`"},
    {"7", "5", "0.7990635300581406`", "1.3352319976637008`", 
     "6.289030419953237`"},
    {"9", "7", "0.8457402901133606`", "2.5181175536768174`", 
     "12.167331157250084`"},
    {"11", "9", "0.8747820899988616`", "4.061790895759117`", 
     "19.96391205509064`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.8115850396579514`*^9},
 CellLabel->
  "Out[5]//TableForm=",ExpressionUUID->"86a17e03-69b8-4b6f-9f13-ba06f30b9057"]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{907, 572},
WindowMargins->{{207, Automatic}, {Automatic, 170}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"c0c8f4e8-974b-4c29-abf6-13fd00839990"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 107, 0, 67, "Section",ExpressionUUID->"4ba0636f-1639-4e46-af9b-04af528f9ad0"],
Cell[668, 22, 276, 9, 49, "Text",ExpressionUUID->"913de107-c161-4c3b-9f79-efc9982c274e"],
Cell[947, 33, 559, 13, 192, "Input",ExpressionUUID->"43f48678-84f2-41ed-ac5a-56159826e0e8"],
Cell[1509, 48, 803, 30, 53, "Text",ExpressionUUID->"864d858a-8ec7-4dec-bd48-f8aad737966a"],
Cell[2315, 80, 749, 20, 300, "Input",ExpressionUUID->"8588d9ca-c17f-45a2-8356-ad3aad4ab663"],
Cell[3067, 102, 162, 3, 53, "Text",ExpressionUUID->"715e3b9b-89ca-47e8-828f-a8b583f7d4f7"],
Cell[3232, 107, 234, 5, 48, "Input",ExpressionUUID->"f45e9f14-e1f7-4fc7-bd95-c945ced2caff"],
Cell[3469, 114, 160, 3, 53, "Text",ExpressionUUID->"e009b77f-2601-4fe0-9112-97261ef4393d"],
Cell[3632, 119, 168, 2, 30, "Input",ExpressionUUID->"09be7e2a-89c7-4fec-a471-c1855bc07bd9"],
Cell[3803, 123, 146, 3, 53, "Text",ExpressionUUID->"ad334172-f303-4e05-b03f-5d22122516d6"],
Cell[3952, 128, 143, 2, 30, "Input",ExpressionUUID->"65913616-951a-4a9a-9055-a326865bbdb7"],
Cell[4098, 132, 1517, 35, 196, "Output",ExpressionUUID->"86a17e03-69b8-4b6f-9f13-ba06f30b9057"]
}
]
*)

(* End of internal cache information *)

